@@ -98,11 +98,13 @@ types: list[str] = [
     "AWS::Batch::JobQueue",
     "AWS::Batch::SchedulingPolicy",
     "AWS::Batch::ServiceEnvironment",
+    "AWS::Bedrock::DataSource",
     "AWS::Bedrock::Flow",
     "AWS::Bedrock::FlowAlias",
     "AWS::Bedrock::FlowVersion",
     "AWS::Bedrock::Guardrail",
     "AWS::Bedrock::GuardrailVersion",
+    "AWS::Bedrock::KnowledgeBase",
     "AWS::Bedrock::Prompt",
     "AWS::Bedrock::PromptVersion",
     "AWS::CDK::Metadata",
@@ -244,6 +246,7 @@ types: list[str] = [
     "AWS::EC2::Instance",
     "AWS::EC2::InstanceConnectEndpoint",
     "AWS::EC2::InternetGateway",
+    "AWS::EC2::IpPoolRouteTableAssociation",
     "AWS::EC2::KeyPair",
     "AWS::EC2::LaunchTemplate",
     "AWS::EC2::NatGateway",
@@ -331,6 +334,7 @@ types: list[str] = [
     "AWS::EMR::SecurityConfiguration",
     "AWS::EMR::Step",
     "AWS::EMRContainers::VirtualCluster",
+    "AWS::EMRServerless::Application",
     "AWS::ElastiCache::CacheCluster",
     "AWS::ElastiCache::GlobalReplicationGroup",
     "AWS::ElastiCache::ParameterGroup",
@@ -398,7 +402,9 @@ types: list[str] = [
     "AWS::GuardDuty::Master",
     "AWS::GuardDuty::Member",
     "AWS::GuardDuty::PublishingDestination",
+    "AWS::GuardDuty::ThreatEntitySet",
     "AWS::GuardDuty::ThreatIntelSet",
+    "AWS::GuardDuty::TrustedEntitySet",
     "AWS::IAM::AccessKey",
     "AWS::IAM::Group",
     "AWS::IAM::GroupPolicy",
@@ -437,6 +443,7 @@ types: list[str] = [
     "AWS::KMS::Alias",
     "AWS::KMS::Key",
     "AWS::KMS::ReplicaKey",
+    "AWS::KafkaConnect::Connector",
     "AWS::KafkaConnect::CustomPlugin",
     "AWS::KafkaConnect::WorkerConfiguration",
     "AWS::Kinesis::ResourcePolicy",
@@ -567,6 +574,7 @@ types: list[str] = [
     "AWS::RDS::DBProxyTargetGroup",
     "AWS::RDS::DBSecurityGroup",
     "AWS::RDS::DBSecurityGroupIngress",
+    "AWS::RDS::DBShardGroup",
     "AWS::RDS::DBSubnetGroup",
     "AWS::RDS::EventSubscription",
     "AWS::RDS::GlobalCluster",
@@ -782,6 +790,7 @@ cached: list[str] = [
     "aws-apigateway-model.json",
     "aws-apigateway-requestvalidator.json",
     "aws-apigateway-resource.json",
+    "aws-apigateway-restapi.json",
     "aws-apigateway-stage.json",
     "aws-apigateway-usageplan.json",
     "aws-apigateway-usageplankey.json",
@@ -804,11 +813,13 @@ cached: list[str] = [
     "aws-appconfig-configurationprofile.json",
     "aws-appconfig-deployment.json",
     "aws-appconfig-deploymentstrategy.json",
+    "aws-appconfig-environment.json",
     "aws-appconfig-extension.json",
     "aws-appconfig-extensionassociation.json",
     "aws-appconfig-hostedconfigurationversion.json",
     "aws-applicationautoscaling-scalabletarget.json",
     "aws-applicationautoscaling-scalingpolicy.json",
+    "aws-applicationinsights-application.json",
     "aws-applicationsignals-discovery.json",
     "aws-applicationsignals-servicelevelobjective.json",
     "aws-appsync-api.json",
@@ -846,13 +857,16 @@ cached: list[str] = [
     "aws-batch-computeenvironment.json",
     "aws-batch-consumableresource.json",
     "aws-batch-jobdefinition.json",
+    "aws-batch-jobqueue.json",
     "aws-batch-schedulingpolicy.json",
     "aws-batch-serviceenvironment.json",
+    "aws-bedrock-datasource.json",
     "aws-bedrock-flow.json",
     "aws-bedrock-flowalias.json",
     "aws-bedrock-flowversion.json",
     "aws-bedrock-guardrail.json",
     "aws-bedrock-guardrailversion.json",
+    "aws-bedrock-knowledgebase.json",
     "aws-bedrock-prompt.json",
     "aws-bedrock-promptversion.json",
     "aws-ce-anomalymonitor.json",
@@ -880,7 +894,6 @@ cached: list[str] = [
     "aws-cloudfront-cloudfrontoriginaccessidentity.json",
     "aws-cloudfront-connectiongroup.json",
     "aws-cloudfront-continuousdeploymentpolicy.json",
-    "aws-cloudfront-function.json",
     "aws-cloudfront-keygroup.json",
     "aws-cloudfront-keyvaluestore.json",
     "aws-cloudfront-monitoringsubscription.json",
@@ -957,6 +970,8 @@ cached: list[str] = [
     "aws-docdb-dbinstance.json",
     "aws-docdb-dbsubnetgroup.json",
     "aws-docdb-eventsubscription.json",
+    "aws-dynamodb-globaltable.json",
+    "aws-dynamodb-table.json",
     "aws-ec2-capacityreservation.json",
     "aws-ec2-capacityreservationfleet.json",
     "aws-ec2-clientvpnendpoint.json",
@@ -980,6 +995,7 @@ cached: list[str] = [
     "aws-ec2-ipamresourcediscovery.json",
     "aws-ec2-ipamresourcediscoveryassociation.json",
     "aws-ec2-ipamscope.json",
+    "aws-ec2-ippoolroutetableassociation.json",
     "aws-ec2-keypair.json",
     "aws-ec2-launchtemplate.json",
     "aws-ec2-natgateway.json",
@@ -1033,7 +1049,6 @@ cached: list[str] = [
     "aws-ec2-vpcendpointservicepermissions.json",
     "aws-ec2-vpcgatewayattachment.json",
     "aws-ec2-vpcpeeringconnection.json",
-    "aws-ec2-vpnconnection.json",
     "aws-ec2-vpnconnectionroute.json",
     "aws-ec2-vpngateway.json",
     "aws-ec2-vpngatewayroutepropagation.json",
@@ -1044,6 +1059,7 @@ cached: list[str] = [
     "aws-ecr-repository.json",
     "aws-ecr-repositorycreationtemplate.json",
     "aws-ecs-capacityprovider.json",
+    "aws-ecs-cluster.json",
     "aws-ecs-clustercapacityproviderassociations.json",
     "aws-ecs-primarytaskset.json",
     "aws-ecs-service.json",
@@ -1066,9 +1082,11 @@ cached: list[str] = [
     "aws-elasticache-securitygroup.json",
     "aws-elasticache-securitygroupingress.json",
     "aws-elasticache-serverlesscache.json",
+    "aws-elasticache-subnetgroup.json",
     "aws-elasticache-user.json",
     "aws-elasticache-usergroup.json",
     "aws-elasticloadbalancing-loadbalancer.json",
+    "aws-elasticloadbalancingv2-listener.json",
     "aws-elasticloadbalancingv2-listenercertificate.json",
     "aws-elasticloadbalancingv2-listenerrule.json",
     "aws-elasticloadbalancingv2-loadbalancer.json",
@@ -1082,6 +1100,7 @@ cached: list[str] = [
     "aws-emr-securityconfiguration.json",
     "aws-emr-step.json",
     "aws-emrcontainers-virtualcluster.json",
+    "aws-emrserverless-application.json",
     "aws-events-apidestination.json",
     "aws-events-archive.json",
     "aws-events-connection.json",
@@ -1123,7 +1142,9 @@ cached: list[str] = [
     "aws-guardduty-master.json",
     "aws-guardduty-member.json",
     "aws-guardduty-publishingdestination.json",
+    "aws-guardduty-threatentityset.json",
     "aws-guardduty-threatintelset.json",
+    "aws-guardduty-trustedentityset.json",
     "aws-iam-group.json",
     "aws-iam-grouppolicy.json",
     "aws-iam-instanceprofile.json",
@@ -1153,12 +1174,14 @@ cached: list[str] = [
     "aws-inspectorv2-filter.json",
     "aws-internetmonitor-monitor.json",
     "aws-iot-thingprincipalattachment.json",
+    "aws-kafkaconnect-connector.json",
     "aws-kafkaconnect-customplugin.json",
     "aws-kafkaconnect-workerconfiguration.json",
     "aws-kinesis-resourcepolicy.json",
     "aws-kinesis-stream.json",
     "aws-kinesis-streamconsumer.json",
     "aws-kinesisanalyticsv2-application.json",
+    "aws-kinesisfirehose-deliverystream.json",
     "aws-kms-alias.json",
     "aws-kms-key.json",
     "aws-kms-replicakey.json",
@@ -1176,10 +1199,13 @@ cached: list[str] = [
     "aws-lambda-permission.json",
     "aws-lambda-version.json",
     "aws-launchwizard-deployment.json",
+    "aws-logs-accountpolicy.json",
     "aws-logs-delivery.json",
     "aws-logs-deliverydestination.json",
     "aws-logs-deliverysource.json",
+    "aws-logs-destination.json",
     "aws-logs-loganomalydetector.json",
+    "aws-logs-loggroup.json",
     "aws-logs-logstream.json",
     "aws-logs-metricfilter.json",
     "aws-logs-querydefinition.json",
@@ -1218,7 +1244,10 @@ cached: list[str] = [
     "aws-msk-configuration.json",
     "aws-msk-vpcconnection.json",
     "aws-mwaa-environment.json",
+    "aws-networkfirewall-firewall.json",
+    "aws-networkfirewall-firewallpolicy.json",
     "aws-networkfirewall-loggingconfiguration.json",
+    "aws-networkfirewall-rulegroup.json",
     "aws-networkfirewall-tlsinspectionconfiguration.json",
     "aws-networkfirewall-vpcendpointassociation.json",
     "aws-networkmanager-connectattachment.json",
@@ -1266,6 +1295,7 @@ cached: list[str] = [
     "aws-ram-permission.json",
     "aws-ram-resourceshare.json",
     "aws-rbin-rule.json",
+    "aws-rds-dbcluster.json",
     "aws-rds-dbclusterparametergroup.json",
     "aws-rds-dbinstance.json",
     "aws-rds-dbparametergroup.json",
@@ -1274,18 +1304,22 @@ cached: list[str] = [
     "aws-rds-dbproxytargetgroup.json",
     "aws-rds-dbsecuritygroup.json",
     "aws-rds-dbsecuritygroupingress.json",
+    "aws-rds-dbshardgroup.json",
     "aws-rds-dbsubnetgroup.json",
     "aws-rds-eventsubscription.json",
     "aws-rds-globalcluster.json",
     "aws-rds-integration.json",
     "aws-rds-optiongroup.json",
+    "aws-redshift-cluster.json",
     "aws-redshift-clusterparametergroup.json",
     "aws-redshift-clustersecuritygroup.json",
     "aws-redshift-clustersecuritygroupingress.json",
     "aws-redshift-clustersubnetgroup.json",
+    "aws-redshift-endpointaccess.json",
     "aws-redshift-endpointauthorization.json",
     "aws-redshift-eventsubscription.json",
     "aws-redshift-integration.json",
+    "aws-redshift-scheduledaction.json",
     "aws-redshiftserverless-namespace.json",
     "aws-redshiftserverless-snapshot.json",
     "aws-redshiftserverless-workgroup.json",
@@ -1299,6 +1333,7 @@ cached: list[str] = [
     "aws-rolesanywhere-trustanchor.json",
     "aws-route53-cidrcollection.json",
     "aws-route53-dnssec.json",
+    "aws-route53-hostedzone.json",
     "aws-route53-keysigningkey.json",
     "aws-route53-recordset.json",
     "aws-route53-recordsetgroup.json",
@@ -1319,6 +1354,7 @@ cached: list[str] = [
     "aws-s3-accesspoint.json",
     "aws-s3-bucket.json",
     "aws-s3-bucketpolicy.json",
+    "aws-s3-multiregionaccesspoint.json",
     "aws-s3-multiregionaccesspointpolicy.json",
     "aws-s3objectlambda-accesspoint.json",
     "aws-s3objectlambda-accesspointpolicy.json",
