@@ -107,11 +107,13 @@ types: list[str] = [
     "AWS::Batch::JobQueue",
     "AWS::Batch::SchedulingPolicy",
     "AWS::Batch::ServiceEnvironment",
+    "AWS::Bedrock::DataSource",
     "AWS::Bedrock::Flow",
     "AWS::Bedrock::FlowAlias",
     "AWS::Bedrock::FlowVersion",
     "AWS::Bedrock::Guardrail",
     "AWS::Bedrock::GuardrailVersion",
+    "AWS::Bedrock::KnowledgeBase",
     "AWS::Bedrock::Prompt",
     "AWS::Bedrock::PromptVersion",
     "AWS::CDK::Metadata",
@@ -253,6 +255,7 @@ types: list[str] = [
     "AWS::EC2::Instance",
     "AWS::EC2::InstanceConnectEndpoint",
     "AWS::EC2::InternetGateway",
+    "AWS::EC2::IpPoolRouteTableAssociation",
     "AWS::EC2::KeyPair",
     "AWS::EC2::LaunchTemplate",
     "AWS::EC2::LocalGatewayRoute",
@@ -417,6 +420,8 @@ types: list[str] = [
     "AWS::Glue::Trigger",
     "AWS::Glue::UsageProfile",
     "AWS::Glue::Workflow",
+    "AWS::GreengrassV2::ComponentVersion",
+    "AWS::GreengrassV2::Deployment",
     "AWS::GuardDuty::Detector",
     "AWS::GuardDuty::Filter",
     "AWS::GuardDuty::IPSet",
@@ -424,7 +429,9 @@ types: list[str] = [
     "AWS::GuardDuty::Master",
     "AWS::GuardDuty::Member",
     "AWS::GuardDuty::PublishingDestination",
+    "AWS::GuardDuty::ThreatEntitySet",
     "AWS::GuardDuty::ThreatIntelSet",
+    "AWS::GuardDuty::TrustedEntitySet",
     "AWS::IAM::AccessKey",
     "AWS::IAM::Group",
     "AWS::IAM::GroupPolicy",
@@ -454,18 +461,34 @@ types: list[str] = [
     "AWS::InspectorV2::CisScanConfiguration",
     "AWS::InspectorV2::Filter",
     "AWS::InternetMonitor::Monitor",
+    "AWS::IoT::AccountAuditConfiguration",
     "AWS::IoT::Authorizer",
+    "AWS::IoT::BillingGroup",
     "AWS::IoT::CACertificate",
     "AWS::IoT::Certificate",
     "AWS::IoT::CertificateProvider",
+    "AWS::IoT::Command",
+    "AWS::IoT::CustomMetric",
+    "AWS::IoT::Dimension",
     "AWS::IoT::DomainConfiguration",
+    "AWS::IoT::EncryptionConfiguration",
+    "AWS::IoT::FleetMetric",
+    "AWS::IoT::JobTemplate",
+    "AWS::IoT::MitigationAction",
     "AWS::IoT::Policy",
     "AWS::IoT::PolicyPrincipalAttachment",
     "AWS::IoT::ProvisioningTemplate",
     "AWS::IoT::RoleAlias",
+    "AWS::IoT::ScheduledAudit",
+    "AWS::IoT::SecurityProfile",
+    "AWS::IoT::SoftwarePackage",
+    "AWS::IoT::SoftwarePackageVersion",
     "AWS::IoT::Thing",
+    "AWS::IoT::ThingGroup",
     "AWS::IoT::ThingPrincipalAttachment",
+    "AWS::IoT::ThingType",
     "AWS::IoT::TopicRule",
+    "AWS::IoT::TopicRuleDestination",
     "AWS::KMS::Alias",
     "AWS::KMS::Key",
     "AWS::KMS::ReplicaKey",
@@ -474,6 +497,8 @@ types: list[str] = [
     "AWS::Kinesis::StreamConsumer",
     "AWS::KinesisAnalyticsV2::Application",
     "AWS::KinesisFirehose::DeliveryStream",
+    "AWS::KinesisVideo::SignalingChannel",
+    "AWS::KinesisVideo::Stream",
     "AWS::LakeFormation::DataCellsFilter",
     "AWS::LakeFormation::DataLakeSettings",
     "AWS::LakeFormation::Permissions",
@@ -602,6 +627,7 @@ types: list[str] = [
     "AWS::RDS::DBProxyTargetGroup",
     "AWS::RDS::DBSecurityGroup",
     "AWS::RDS::DBSecurityGroupIngress",
+    "AWS::RDS::DBShardGroup",
     "AWS::RDS::DBSubnetGroup",
     "AWS::RDS::EventSubscription",
     "AWS::RDS::GlobalCluster",
@@ -827,6 +853,7 @@ cached: list[str] = [
     "aws-apigateway-model.json",
     "aws-apigateway-requestvalidator.json",
     "aws-apigateway-resource.json",
+    "aws-apigateway-restapi.json",
     "aws-apigateway-stage.json",
     "aws-apigateway-usageplan.json",
     "aws-apigateway-usageplankey.json",
@@ -849,11 +876,13 @@ cached: list[str] = [
     "aws-appconfig-configurationprofile.json",
     "aws-appconfig-deployment.json",
     "aws-appconfig-deploymentstrategy.json",
+    "aws-appconfig-environment.json",
     "aws-appconfig-extension.json",
     "aws-appconfig-extensionassociation.json",
     "aws-appconfig-hostedconfigurationversion.json",
     "aws-applicationautoscaling-scalabletarget.json",
     "aws-applicationautoscaling-scalingpolicy.json",
+    "aws-applicationinsights-application.json",
     "aws-applicationsignals-discovery.json",
     "aws-applicationsignals-servicelevelobjective.json",
     "aws-appmesh-gatewayroute.json",
@@ -900,13 +929,16 @@ cached: list[str] = [
     "aws-batch-computeenvironment.json",
     "aws-batch-consumableresource.json",
     "aws-batch-jobdefinition.json",
+    "aws-batch-jobqueue.json",
     "aws-batch-schedulingpolicy.json",
     "aws-batch-serviceenvironment.json",
+    "aws-bedrock-datasource.json",
     "aws-bedrock-flow.json",
     "aws-bedrock-flowalias.json",
     "aws-bedrock-flowversion.json",
     "aws-bedrock-guardrail.json",
     "aws-bedrock-guardrailversion.json",
+    "aws-bedrock-knowledgebase.json",
     "aws-bedrock-prompt.json",
     "aws-bedrock-promptversion.json",
     "aws-ce-anomalymonitor.json",
@@ -934,6 +966,7 @@ cached: list[str] = [
     "aws-cloudfront-cloudfrontoriginaccessidentity.json",
     "aws-cloudfront-connectiongroup.json",
     "aws-cloudfront-continuousdeploymentpolicy.json",
+    "aws-cloudfront-distribution.json",
     "aws-cloudfront-distributiontenant.json",
     "aws-cloudfront-function.json",
     "aws-cloudfront-keygroup.json",
@@ -1012,6 +1045,8 @@ cached: list[str] = [
     "aws-docdb-dbinstance.json",
     "aws-docdb-dbsubnetgroup.json",
     "aws-docdb-eventsubscription.json",
+    "aws-dynamodb-globaltable.json",
+    "aws-dynamodb-table.json",
     "aws-ec2-capacityreservation.json",
     "aws-ec2-capacityreservationfleet.json",
     "aws-ec2-clientvpnendpoint.json",
@@ -1035,6 +1070,7 @@ cached: list[str] = [
     "aws-ec2-ipamresourcediscovery.json",
     "aws-ec2-ipamresourcediscoveryassociation.json",
     "aws-ec2-ipamscope.json",
+    "aws-ec2-ippoolroutetableassociation.json",
     "aws-ec2-keypair.json",
     "aws-ec2-launchtemplate.json",
     "aws-ec2-localgatewayroute.json",
@@ -1096,7 +1132,6 @@ cached: list[str] = [
     "aws-ec2-vpcendpointservicepermissions.json",
     "aws-ec2-vpcgatewayattachment.json",
     "aws-ec2-vpcpeeringconnection.json",
-    "aws-ec2-vpnconnection.json",
     "aws-ec2-vpnconnectionroute.json",
     "aws-ec2-vpngateway.json",
     "aws-ec2-vpngatewayroutepropagation.json",
@@ -1107,6 +1142,7 @@ cached: list[str] = [
     "aws-ecr-repository.json",
     "aws-ecr-repositorycreationtemplate.json",
     "aws-ecs-capacityprovider.json",
+    "aws-ecs-cluster.json",
     "aws-ecs-clustercapacityproviderassociations.json",
     "aws-ecs-primarytaskset.json",
     "aws-ecs-service.json",
@@ -1129,9 +1165,11 @@ cached: list[str] = [
     "aws-elasticache-securitygroup.json",
     "aws-elasticache-securitygroupingress.json",
     "aws-elasticache-serverlesscache.json",
+    "aws-elasticache-subnetgroup.json",
     "aws-elasticache-user.json",
     "aws-elasticache-usergroup.json",
     "aws-elasticloadbalancing-loadbalancer.json",
+    "aws-elasticloadbalancingv2-listener.json",
     "aws-elasticloadbalancingv2-listenercertificate.json",
     "aws-elasticloadbalancingv2-listenerrule.json",
     "aws-elasticloadbalancingv2-loadbalancer.json",
@@ -1153,7 +1191,6 @@ cached: list[str] = [
     "aws-events-connection.json",
     "aws-events-eventbus.json",
     "aws-events-eventbuspolicy.json",
-    "aws-events-rule.json",
     "aws-eventschemas-discoverer.json",
     "aws-eventschemas-registry.json",
     "aws-eventschemas-registrypolicy.json",
@@ -1188,6 +1225,8 @@ cached: list[str] = [
     "aws-glue-trigger.json",
     "aws-glue-usageprofile.json",
     "aws-glue-workflow.json",
+    "aws-greengrassv2-componentversion.json",
+    "aws-greengrassv2-deployment.json",
     "aws-guardduty-detector.json",
     "aws-guardduty-filter.json",
     "aws-guardduty-ipset.json",
@@ -1195,7 +1234,9 @@ cached: list[str] = [
     "aws-guardduty-master.json",
     "aws-guardduty-member.json",
     "aws-guardduty-publishingdestination.json",
+    "aws-guardduty-threatentityset.json",
     "aws-guardduty-threatintelset.json",
+    "aws-guardduty-trustedentityset.json",
     "aws-iam-group.json",
     "aws-iam-grouppolicy.json",
     "aws-iam-instanceprofile.json",
@@ -1224,19 +1265,40 @@ cached: list[str] = [
     "aws-inspectorv2-cisscanconfiguration.json",
     "aws-inspectorv2-filter.json",
     "aws-internetmonitor-monitor.json",
+    "aws-iot-accountauditconfiguration.json",
     "aws-iot-authorizer.json",
+    "aws-iot-billinggroup.json",
     "aws-iot-cacertificate.json",
     "aws-iot-certificate.json",
     "aws-iot-certificateprovider.json",
+    "aws-iot-command.json",
+    "aws-iot-custommetric.json",
+    "aws-iot-dimension.json",
     "aws-iot-domainconfiguration.json",
+    "aws-iot-encryptionconfiguration.json",
+    "aws-iot-fleetmetric.json",
+    "aws-iot-jobtemplate.json",
+    "aws-iot-mitigationaction.json",
     "aws-iot-policy.json",
     "aws-iot-provisioningtemplate.json",
     "aws-iot-rolealias.json",
+    "aws-iot-scheduledaudit.json",
+    "aws-iot-securityprofile.json",
+    "aws-iot-softwarepackage.json",
+    "aws-iot-softwarepackageversion.json",
+    "aws-iot-thing.json",
+    "aws-iot-thinggroup.json",
     "aws-iot-thingprincipalattachment.json",
+    "aws-iot-thingtype.json",
+    "aws-iot-topicrule.json",
+    "aws-iot-topicruledestination.json",
     "aws-kinesis-resourcepolicy.json",
     "aws-kinesis-stream.json",
     "aws-kinesis-streamconsumer.json",
     "aws-kinesisanalyticsv2-application.json",
+    "aws-kinesisfirehose-deliverystream.json",
+    "aws-kinesisvideo-signalingchannel.json",
+    "aws-kinesisvideo-stream.json",
     "aws-kms-alias.json",
     "aws-kms-key.json",
     "aws-kms-replicakey.json",
@@ -1261,10 +1323,13 @@ cached: list[str] = [
     "aws-location-routecalculator.json",
     "aws-location-tracker.json",
     "aws-location-trackerconsumer.json",
+    "aws-logs-accountpolicy.json",
     "aws-logs-delivery.json",
     "aws-logs-deliverydestination.json",
     "aws-logs-deliverysource.json",
+    "aws-logs-destination.json",
     "aws-logs-loganomalydetector.json",
+    "aws-logs-loggroup.json",
     "aws-logs-logstream.json",
     "aws-logs-metricfilter.json",
     "aws-logs-querydefinition.json",
@@ -1290,7 +1355,10 @@ cached: list[str] = [
     "aws-neptune-dbinstance.json",
     "aws-neptune-dbparametergroup.json",
     "aws-neptune-dbsubnetgroup.json",
+    "aws-networkfirewall-firewall.json",
+    "aws-networkfirewall-firewallpolicy.json",
     "aws-networkfirewall-loggingconfiguration.json",
+    "aws-networkfirewall-rulegroup.json",
     "aws-networkfirewall-tlsinspectionconfiguration.json",
     "aws-networkfirewall-vpcendpointassociation.json",
     "aws-networkmanager-connectattachment.json",
@@ -1348,6 +1416,7 @@ cached: list[str] = [
     "aws-ram-permission.json",
     "aws-ram-resourceshare.json",
     "aws-rbin-rule.json",
+    "aws-rds-dbcluster.json",
     "aws-rds-dbclusterparametergroup.json",
     "aws-rds-dbinstance.json",
     "aws-rds-dbparametergroup.json",
@@ -1356,18 +1425,22 @@ cached: list[str] = [
     "aws-rds-dbproxytargetgroup.json",
     "aws-rds-dbsecuritygroup.json",
     "aws-rds-dbsecuritygroupingress.json",
+    "aws-rds-dbshardgroup.json",
     "aws-rds-dbsubnetgroup.json",
     "aws-rds-eventsubscription.json",
     "aws-rds-globalcluster.json",
     "aws-rds-integration.json",
     "aws-rds-optiongroup.json",
+    "aws-redshift-cluster.json",
     "aws-redshift-clusterparametergroup.json",
     "aws-redshift-clustersecuritygroup.json",
     "aws-redshift-clustersecuritygroupingress.json",
     "aws-redshift-clustersubnetgroup.json",
+    "aws-redshift-endpointaccess.json",
     "aws-redshift-endpointauthorization.json",
     "aws-redshift-eventsubscription.json",
     "aws-redshift-integration.json",
+    "aws-redshift-scheduledaction.json",
     "aws-redshiftserverless-namespace.json",
     "aws-redshiftserverless-snapshot.json",
     "aws-redshiftserverless-workgroup.json",
@@ -1382,6 +1455,7 @@ cached: list[str] = [
     "aws-rolesanywhere-trustanchor.json",
     "aws-route53-cidrcollection.json",
     "aws-route53-dnssec.json",
+    "aws-route53-hostedzone.json",
     "aws-route53-keysigningkey.json",
     "aws-route53-recordset.json",
     "aws-route53-recordsetgroup.json",
@@ -1402,6 +1476,7 @@ cached: list[str] = [
     "aws-s3-accesspoint.json",
     "aws-s3-bucket.json",
     "aws-s3-bucketpolicy.json",
+    "aws-s3-multiregionaccesspoint.json",
     "aws-s3-multiregionaccesspointpolicy.json",
     "aws-s3objectlambda-accesspoint.json",
     "aws-s3objectlambda-accesspointpolicy.json",
@@ -1412,6 +1487,7 @@ cached: list[str] = [
     "aws-s3tables-tablepolicy.json",
     "aws-sagemaker-app.json",
     "aws-sagemaker-appimageconfig.json",
+    "aws-sagemaker-cluster.json",
     "aws-sagemaker-domain.json",
     "aws-sagemaker-featuregroup.json",
     "aws-sagemaker-image.json",
