@@ -7,6 +7,7 @@ types: list[str] = [
     "AWS::ACMPCA::CertificateAuthorityActivation",
     "AWS::ACMPCA::Permission",
     "AWS::AIOps::InvestigationGroup",
+    "AWS::APS::ResourcePolicy",
     "AWS::APS::RuleGroupsNamespace",
     "AWS::APS::Scraper",
     "AWS::APS::Workspace",
@@ -375,6 +376,7 @@ types: list[str] = [
     "AWS::DataZone::EnvironmentProfile",
     "AWS::DataZone::GroupProfile",
     "AWS::DataZone::Owner",
+    "AWS::DataZone::PolicyGrant",
     "AWS::DataZone::Project",
     "AWS::DataZone::ProjectMembership",
     "AWS::DataZone::ProjectProfile",
@@ -434,6 +436,7 @@ types: list[str] = [
     "AWS::EC2::Instance",
     "AWS::EC2::InstanceConnectEndpoint",
     "AWS::EC2::InternetGateway",
+    "AWS::EC2::IpPoolRouteTableAssociation",
     "AWS::EC2::KeyPair",
     "AWS::EC2::LaunchTemplate",
     "AWS::EC2::LocalGatewayRoute",
@@ -674,7 +677,9 @@ types: list[str] = [
     "AWS::GuardDuty::Master",
     "AWS::GuardDuty::Member",
     "AWS::GuardDuty::PublishingDestination",
+    "AWS::GuardDuty::ThreatEntitySet",
     "AWS::GuardDuty::ThreatIntelSet",
+    "AWS::GuardDuty::TrustedEntitySet",
     "AWS::HealthImaging::Datastore",
     "AWS::HealthLake::FHIRDatastore",
     "AWS::IAM::AccessKey",
@@ -720,6 +725,8 @@ types: list[str] = [
     "AWS::Inspector::AssessmentTemplate",
     "AWS::Inspector::ResourceGroup",
     "AWS::InspectorV2::CisScanConfiguration",
+    "AWS::InspectorV2::CodeSecurityIntegration",
+    "AWS::InspectorV2::CodeSecurityScanConfiguration",
     "AWS::InspectorV2::Filter",
     "AWS::InternetMonitor::Monitor",
     "AWS::Invoicing::InvoiceUnit",
@@ -733,6 +740,7 @@ types: list[str] = [
     "AWS::IoT::CustomMetric",
     "AWS::IoT::Dimension",
     "AWS::IoT::DomainConfiguration",
+    "AWS::IoT::EncryptionConfiguration",
     "AWS::IoT::FleetMetric",
     "AWS::IoT::JobTemplate",
     "AWS::IoT::Logging",
